@@ -265,6 +265,20 @@ class MakeConfigDriveTest(test_utils.BaseTestCase):
                                 '-quiet', '-J', '-r', '-V',
                                 'config-2', mock.ANY]
 
+        self.mkisofs_cmd = ['mkisofs', '-o', mock.ANY,
+                            '-ldots', '-allow-lowercase',
+                            '-allow-multidot', '-l',
+                            '-publisher', 'ironicclient-configdrive 0.1',
+                            '-quiet', '-J', '-r', '-V',
+                            'config-2', mock.ANY]
+
+        self.xorrisofs_cmd = ['xorrisofs', '-o', mock.ANY,
+                              '-ldots', '-allow-lowercase',
+                              '-allow-multidot', '-l',
+                              '-publisher', 'ironicclient-configdrive 0.1',
+                              '-quiet', '-J', '-r', '-V',
+                              'config-2', mock.ANY]
+
     def test_make_configdrive(self, mock_popen):
         fake_process = mock.Mock(returncode=0)
         fake_process.communicate.return_value = ('', '')
@@ -278,6 +292,24 @@ class MakeConfigDriveTest(test_utils.BaseTestCase):
                                            stdout=subprocess.PIPE)
         fake_process.communicate.assert_called_once_with()
 
+    def test_make_configdrive_fallsback(self, mock_popen):
+        fake_process = mock.Mock(returncode=0)
+        fake_process.communicate.return_value = ('', '')
+        mock_popen.side_effect = iter([OSError('boom'),
+                                       OSError('boom'),
+                                       fake_process])
+        with utils.tempdir() as dirname:
+            utils.make_configdrive(dirname)
+        mock_popen.assert_has_calls([
+            mock.call(self.genisoimage_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE),
+            mock.call(self.mkisofs_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE),
+            mock.call(self.xorrisofs_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE)
+        ])
+        fake_process.communicate.assert_called_once_with()
+
     @mock.patch.object(os, 'access', autospec=True)
     def test_make_configdrive_non_readable_dir(self, mock_access, mock_popen):
         mock_access.return_value = False
@@ -292,9 +324,14 @@ class MakeConfigDriveTest(test_utils.BaseTestCase):
 
         self.assertRaises(exc.CommandError, utils.make_configdrive, 'fake-dir')
         mock_access.assert_called_once_with('fake-dir', os.R_OK)
-        mock_popen.assert_called_once_with(self.genisoimage_cmd,
-                                           stderr=subprocess.PIPE,
-                                           stdout=subprocess.PIPE)
+        mock_popen.assert_has_calls([
+            mock.call(self.genisoimage_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE),
+            mock.call(self.mkisofs_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE),
+            mock.call(self.xorrisofs_cmd, stderr=subprocess.PIPE,
+                      stdout=subprocess.PIPE)
+        ])
 
     @mock.patch.object(os, 'access', autospec=True)
     def test_make_configdrive_non_zero_returncode(self, mock_access,
@@ -340,9 +377,9 @@ class HandleJsonFileTest(test_utils.BaseTestCase):
         self.assertEqual(json.loads(cleansteps), steps)
 
     def test_handle_json_or_file_arg_bad_json(self):
-        cleansteps = 'foo'
+        cleansteps = '{foo invalid: json{'
         self.assertRaisesRegex(exc.InvalidAttribute,
-                               'For JSON',
+                               'is not a file and cannot be parsed as JSON',
                                utils.handle_json_or_file_arg, cleansteps)
 
     def test_handle_json_or_file_arg_file(self):
@@ -355,17 +392,24 @@ class HandleJsonFileTest(test_utils.BaseTestCase):
 
         self.assertEqual(json.loads(contents), steps)
 
+    def test_handle_yaml_or_file_arg_file(self):
+        contents = '''---
+- step: upgrade
+  interface: deploy'''
+
+        with tempfile.NamedTemporaryFile(mode='w') as f:
+            f.write(contents)
+            f.flush()
+            steps = utils.handle_json_or_file_arg(f.name)
+
+        self.assertEqual([{"step": "upgrade", "interface": "deploy"}], steps)
+
     @mock.patch.object(builtins, 'open', autospec=True)
     def test_handle_json_or_file_arg_file_fail(self, mock_open):
-        mock_file_object = mock.MagicMock()
-        mock_file_handle = mock.MagicMock()
-        mock_file_handle.__enter__.return_value = mock_file_object
-        mock_open.return_value = mock_file_handle
-        mock_file_object.read.side_effect = IOError
+        mock_open.return_value.__enter__.side_effect = IOError
 
         with tempfile.NamedTemporaryFile(mode='w') as f:
             self.assertRaisesRegex(exc.InvalidAttribute,
                                    "from file",
                                    utils.handle_json_or_file_arg, f.name)
             mock_open.assert_called_once_with(f.name, 'r')
-            mock_file_object.read.assert_called_once_with()
