@@ -34,12 +34,13 @@ class Resource(object):
         'address': 'Address',
         'alive': 'Alive',
         'allocation_uuid': 'Allocation UUID',
+        'allowable_values': 'Allowable Values',
         'async': 'Async',
+        'attribute_type': 'Attribute Type',
         'automated_clean': 'Automated Clean',
         'attach': 'Response is attachment',
-        'bios_name': 'BIOS setting name',
-        'bios_value': 'BIOS setting value',
         'boot_index': 'Boot Index',
+        'boot_mode': 'Boot Mode',
         'candidate_nodes': 'Candidate Nodes',
         'chassis_uuid': 'Chassis UUID',
         'clean_step': 'Clean Step',
@@ -78,6 +79,8 @@ class Resource(object):
         'enabled_storage_interfaces': 'Enabled Storage Interfaces',
         'enabled_vendor_interfaces': 'Enabled Vendor Interfaces',
         'extra': 'Extra',
+        'event': 'Description of the event',
+        'event_type': 'Event Origin Type',
         'hostname': 'Hostname',
         'hosts': 'Active host(s)',
         'http_methods': 'Supported HTTP methods',
@@ -88,9 +91,12 @@ class Resource(object):
         'internal_info': 'Internal Info',
         'last_error': 'Last Error',
         'lessee': 'Lessee',
+        'lower_bound': 'Lower Bound',
         'maintenance': 'Maintenance',
         'maintenance_reason': 'Maintenance Reason',
+        'max_length': 'Maximum Length',
         'fault': 'Fault',
+        'min_length': 'Minimum Length',
         'mode': 'Mode',
         'name': 'Name',
         'network_data': 'Network Configuration',
@@ -103,10 +109,13 @@ class Resource(object):
         'provision_state': 'Provisioning State',
         'provision_updated_at': 'Provision Updated At',
         'raid_config': 'Current RAID configuration',
+        'read_only': 'Read Only',
+        'reset_required': 'Reset Required',
         'reservation': 'Reservation',
         'resource_class': 'Resource Class',
         'retired': 'Retired',
         'retired_reason': 'Retired Reason',
+        'secure_boot': 'Secure Boot',
         'state': 'State',
         'steps': 'Steps',
         'target_power_state': 'Target Power State',
@@ -116,6 +125,7 @@ class Resource(object):
         'type': 'Type',
         'updated_at': 'Updated At',
         'uuid': 'UUID',
+        'value': 'Value',
         'volume_id': 'Volume ID',
         'volume_type': 'Driver Volume Type',
         'local_link_connection': 'Local Link Connection',
@@ -132,6 +142,10 @@ class Resource(object):
         'raid_interface': 'RAID Interface',
         'rescue_interface': 'Rescue Interface',
         'storage_interface': 'Storage Interface',
+        'severity': 'Severity',
+        'unique': 'Unique',
+        'upper_bound': 'Upper Bound',
+        'user': 'User',
         'vendor_interface': 'Vendor Interface',
         'standalone_ports_supported': 'Standalone Ports Supported',
         'physical_network': 'Physical Network',
@@ -223,6 +237,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'automated_clean',
      'bios_interface',
      'boot_interface',
+     'boot_mode',
      'chassis_uuid',
      'clean_step',
      'conductor',
@@ -266,6 +281,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'resource_class',
      'retired',
      'retired_reason',
+     'secure_boot',
      'storage_interface',
      'target_power_state',
      'target_provision_state',
@@ -377,7 +393,24 @@ TRAIT_RESOURCE = Resource(
 )
 
 BIOS_RESOURCE = Resource(
-    ['bios_name', 'bios_value'],
+    ['name', 'value'],
+    override_labels={'name': 'BIOS setting name',
+                     'value': 'BIOS setting value'}
+)
+
+BIOS_DETAILED_RESOURCE = Resource(
+    ['name',
+     'value',
+     'attribute_type',
+     'allowable_values',
+     'lower_bound',
+     'min_length',
+     'max_length',
+     'read_only',
+     'reset_required',
+     'unique',
+     'upper_bound'
+     ],
 )
 
 # Drivers
@@ -541,3 +574,21 @@ DEPLOY_TEMPLATE_RESOURCE = Resource(
      'name',
      ],
 )
+
+
+NODE_HISTORY_RESOURCE = Resource(
+    ['uuid',
+     'created_at',
+     'severity',
+     'event']
+)
+
+NODE_HISTORY_DETAILED_RESOURCE = Resource(
+    ['uuid',
+     'created_at',
+     'severity',
+     'event_type',
+     'event',
+     'conductor',
+     'user']
+)
